import{X as s,Y as a}from"./index-BBP3z-Qn.js";const i="wifi_ssid",n="wifi_password",o=async()=>{const a=await s();return a.includes(i)&&a.includes(n)},r=async(s,o)=>a({[i]:s,[n]:o},"Your Wi-Fi SSID and password");export{i as S,n as a,o as c,r as s};
//# sourceMappingURL=c.DN2acm1W.js.map
