import{b as e,n as s,s as o,x as l}from"./index-BBP3z-Qn.js";import"./c.qxZmAkQm.js";import"./c.DAMWOaZB.js";let d=class extends o{render(){return l`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};d=e([s("esphome-update-all-dialog")],d);
//# sourceMappingURL=c.Cr66bVXM.js.map
