import{V as e}from"./index-BBP3z-Qn.js";const i="serial"in navigator,l=window.isSecureContext,s={ESP32:{label:"ESP32",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:"esp32dev"},ESP32S2:{label:"ESP32-S2",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:"esp32-s2-saola-1"},ESP32S3:{label:"ESP32-S3",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:"esp32-s3-devkitc-1"},ESP32C3:{label:"ESP32-C3",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:"esp32-c3-devkitm-1"},ESP32C6:{label:"ESP32-C6",showInPickerTitle:!0,showInDeviceTypePicker:!1,defaultBoard:"esp32-c6-devkitc-1"},ESP8266:{label:"ESP8266",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:"esp01_1m"},RP2040:{label:"Raspberry Pi Pico W",showInPickerTitle:!1,showInDeviceTypePicker:!0,defaultBoard:"rpipicow"},BK72XX:{label:"BK72xx",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:null},RTL87XX:{label:"RTL87xx",showInPickerTitle:!0,showInDeviceTypePicker:!0,defaultBoard:null}},P={ESP32:"ESP32","ESP32-S2":"ESP32S2","ESP32-S3":"ESP32S3","ESP32-C3":"ESP32C3","ESP32-C6":"ESP32C6",ESP8266:"ESP8266"},a=e`
  <svg class="svg-fill-primary" width="24" height="24" viewBox="0 0 24 24" slot="meta">
    <path d="M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z" />
  </svg>
`;export{s as a,l as b,P as c,a as m,i as s};
//# sourceMappingURL=c.DcpxJ3av.js.map
